==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DeploymentDetailsFluentImpl<T extends DeploymentDetailsFluent<T>> extends BaseFluent<T> implements DeploymentDetailsFluent<T>{

     List<VisitableBuilder<DeploymentCause, ?>> causes = new ArrayList();     String message;     Map<String, Object> additionalProperties = new HashMap();

    public T addToCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.add(builder);this.causes.add(builder);} return (T)this;
    }
    public T removeFromCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.remove(builder);this.causes.remove(builder);} return (T)this;
    }
    public List<DeploymentCause> getCauses(){
    return build(causes);
    }
    public T withCauses( List<DeploymentCause> causes){
    this.causes.clear();if (causes != null) {for (DeploymentCause item : causes){this.addToCauses(item);}} return (T) this;
    }
    public T withCauses( DeploymentCause ...causes){
    this.causes.clear(); if (causes != null) {for (DeploymentCause item :causes){ this.addToCauses(item);}} return (T) this;
    }
    public CausesNested<T> addNewCause(){
    return new CausesNestedImpl<T>();
    }
    public CausesNested<T> addNewCauseLike( DeploymentCause item){
    return new CausesNestedImpl<T>(item);
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentDetailsFluentImpl that = (DeploymentDetailsFluentImpl) o;
if (causes != null ? !causes.equals(that.causes) :that.causes != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class CausesNestedImpl<N> extends DeploymentCauseFluentImpl<CausesNested<N>> implements CausesNested<N>{

        private final DeploymentCauseBuilder builder;
    
             CausesNestedImpl (){
        this.builder = new DeploymentCauseBuilder(this);
        }
             CausesNestedImpl ( DeploymentCause item){
        this.builder = new DeploymentCauseBuilder(this, item);
        }
    
            public N endCause(){
            return and();
        }
            public N and(){
            return (N) DeploymentDetailsFluentImpl.this.addToCauses(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.37-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DeploymentDetailsFluentImpl<T extends DeploymentDetailsFluent<T>> extends BaseFluent<T> implements DeploymentDetailsFluent<T>{

     List<VisitableBuilder<DeploymentCause, ?>> causes = new ArrayList();     String message;     Map<String, Object> additionalProperties = new HashMap();
public DeploymentDetailsFluentImpl(){
    
}
public DeploymentDetailsFluentImpl( DeploymentDetails instance ){
    this.withCauses(instance.getCauses()); this.withMessage(instance.getMessage()); 
}

    public T addToCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.add(builder);this.causes.add(builder);} return (T)this;
    }
    public T removeFromCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.remove(builder);this.causes.remove(builder);} return (T)this;
    }
    public List<DeploymentCause> getCauses(){
    return build(causes);
    }
    public T withCauses( List<DeploymentCause> causes){
    this.causes.clear();if (causes != null) {for (DeploymentCause item : causes){this.addToCauses(item);}} return (T) this;
    }
    public T withCauses( DeploymentCause ...causes){
    this.causes.clear(); if (causes != null) {for (DeploymentCause item :causes){ this.addToCauses(item);}} return (T) this;
    }
    public CausesNested<T> addNewCause(){
    return new CausesNestedImpl<T>();
    }
    public CausesNested<T> addNewCauseLike( DeploymentCause item){
    return new CausesNestedImpl<T>(item);
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentDetailsFluentImpl that = (DeploymentDetailsFluentImpl) o;
if (causes != null ? !causes.equals(that.causes) :that.causes != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class CausesNestedImpl<N> extends DeploymentCauseFluentImpl<CausesNested<N>> implements CausesNested<N>{

        private final DeploymentCauseBuilder builder;
    
             CausesNestedImpl (){
        this.builder = new DeploymentCauseBuilder(this);
        }
             CausesNestedImpl ( DeploymentCause item){
        this.builder = new DeploymentCauseBuilder(this, item);
        }
    
            public N endCause(){
            return and();
        }
            public N and(){
            return (N) DeploymentDetailsFluentImpl.this.addToCauses(builder.build());
        }
    
}


}
